@@ -380,9 +380,9 @@ mod tests {
     fn special() {
         let l = MatrixSxS::<f32, 3, 3>::from([[1., 0., 0.], [2., 4., 0.], [3., 5., 6.]]);
         let lt = l.transpose();
-        println!("lt: {}", lt);
+        println!("{}", lt);
         let a = l.matmul(&lt);
-        println!("a: {}", a);
+        println!("{}", a);
     }
     // f32
     // --------------------------------------------------
